From: Matthew Murrian <matthew.murr...@goctsi.com>

The SG capability is inherently present with Multichannel DMA operation.
The register used to check for this capability with other DMA driver types
is not defined for MCDMA.

Fixes: 6ccd692bfb7f ("dmaengine: xilinx_dma: Add Xilinx AXI MCDMA Engine driver 
support")
Signed-off-by: Matthew Murrian <matthew.murr...@goctsi.com>
Signed-off-by: Radhey Shyam Pandey <radhey.shyam.pan...@xilinx.com>
---
 drivers/dma/xilinx/xilinx_dma.c | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/drivers/dma/xilinx/xilinx_dma.c b/drivers/dma/xilinx/xilinx_dma.c
index ade4e6e1a5bd..993297d585c0 100644
--- a/drivers/dma/xilinx/xilinx_dma.c
+++ b/drivers/dma/xilinx/xilinx_dma.c
@@ -2875,10 +2875,11 @@ static int xilinx_dma_chan_probe(struct 
xilinx_dma_device *xdev,
                chan->stop_transfer = xilinx_dma_stop_transfer;
        }
 
        /* check if SG is enabled (only for AXIDMA and CDMA) */
        if (xdev->dma_config->dmatype != XDMA_TYPE_VDMA) {
-               if (dma_ctrl_read(chan, XILINX_DMA_REG_DMASR) &
-                   XILINX_DMA_DMASR_SG_MASK)
+               if (xdev->dma_config->dmatype == XDMA_TYPE_AXIMCDMA ||
+                   dma_ctrl_read(chan, XILINX_DMA_REG_DMASR) &
+                           XILINX_DMA_DMASR_SG_MASK)
                        chan->has_sg = true;
                dev_dbg(chan->dev, "ch %d: SG %s\n", chan->id,
                        chan->has_sg ? "enabled" : "disabled");
@@ -2875,10 +2875,11 @@ static int xilinx_dma_chan_probe(struct 
        }
 
-       /* check if SG is enabled (only for AXIDMA and CDMA) */
+       /* check if SG is enabled (only for AXIDMA, AXIMCDMA, and CDMA) */
        if (xdev->dma_config->dmatype != XDMA_TYPE_VDMA) {
-- 
2.7.4

Reply via email to